/*******************************************************************************
* File Name: ADC_SAR_Seq_1_INT.c
* Version 2.50
*
*  Description:
*    This file contains the code that operates during the ADC_SAR interrupt
*    service routine.
*
*   Note:
*
********************************************************************************
* Copyright 2008-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ADC_SAR_Seq_1.h"
#include "cyapicallbacks.h"


/******************************************************************************
* Custom Declarations and Variables
* - add user inlcude files, prototypes and variables between the following
*   #START and #END tags
******************************************************************************/
/* `#START ADC_SYS_VAR`  */
#include "main.h"
static uint8 loop_index = 0;
/* `#END`  */

#if(ADC_SAR_Seq_1_IRQ_REMOVE == 0u)


    /******************************************************************************
    * Function Name: ADC_SAR_Seq_1_ISR
    *******************************************************************************
    *
    * Summary:
    *  Handle Interrupt Service Routine.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  No.
    *
    ******************************************************************************/
    CY_ISR( ADC_SAR_Seq_1_ISR )
    {
        uint32 intr_status;

        /* Read interrupt status register */
        intr_status = ADC_SAR_Seq_1_SAR_INTR_REG;

        #ifdef ADC_SAR_Seq_1_ISR_INTERRUPT_CALLBACK
            ADC_SAR_Seq_1_ISR_InterruptCallback();
        #endif /* ADC_SAR_Seq_1_ISR_INTERRUPT_CALLBACK */


        /************************************************************************
        *  Custom Code
        *  - add user ISR code between the following #START and #END tags
        *************************************************************************/
        /* `#START MAIN_ADC_ISR`  */
        if(adc_done_flag == 0){
            /* 全チャンネルを掃引しながら、AD変換*/
            for(loop_index=0; loop_index < ADC_CHANNEL; ++loop_index){
                adc_result[loop_index] = ADC_SAR_Seq_1_GetResult16(loop_index);
                /* AD変換値の超過制限 */
                if(adc_result[loop_index] < ADC_MIN){
                    adc_result[loop_index] = ADC_MIN;
                }
                else if(adc_result[loop_index] > ADC_MAX){
                    adc_result[loop_index] = ADC_MAX;
                }
            }
        }
        /* AD変換の完了を main() 関数に知らせるフラグ。初期値は 0 で、AD変換完了の度に1加算。
         *
         * main() 関数側の処理として、本フラグが非0 の場合、AD変換完了と見なし、データ処理してから、
         * 本フラグを 0 に戻すこととする。
         *
         * 本関数側の処理として、本フラグ値が 0 の場合だけ、AD変換結果を更新する。最後に1 を加算する。
         *
         * 換言すると、本フラグ値が 2以上の場合、main() 関数でのデータ処理速度より、AD変換速度の
         * 方が早く、サンプリング欠損していること示している。AD変換速度を遅くする必要がある。
         */
        ++ adc_done_flag;
        
        /* AD変換結果の代わりに、PCへ送信するダミーデータ */
        ++dummy_data;
        if(dummy_data > ADC_MAX){
            dummy_data = 0;
        }
        /* `#END`  */
        
        /* Clear handled interrupt */
        ADC_SAR_Seq_1_SAR_INTR_REG = intr_status;
    }

#endif   /* End ADC_SAR_Seq_1_IRQ_REMOVE */


/* [] END OF FILE */
